California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 1 - AB 531 (CHAPTER 789, STATUTES OF 2023), IRWIN. THE BEHAVIORAL HEALTH INFRASTRUCTURE BOND ACT OF 2023; SB 326 (CHAPTER 790, STATUTES OF 2023), EGGMAN. THE BEHAVIORAL HEALTH SERVICES ACT View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1466985 | JENKINS BALLOT MEASURE COMMITTEE FOR YES ON PROP 1; SF DISTRICT ATTORNEY BROOKE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1466153 | UBER INNOVATION BALLOT MEASURE COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302403 | CALIFORNIA CORRECTIONAL PEACE OFFICERS ASSOCIATION TRUTH IN AMERICAN GOVERNMENT FUND (NON-PROFIT 501 (C) 5) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1463883 | IRWIN'S COMMITTEE TO SUPPORT VETERANS AND THE MENTAL HEALTH SERVICES ACT; YES ON PROPOSITION 1, ASSEMBLYMEMBER JACQUI | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1380675 | NEWSOM'S BALLOT MEASURE COMMITTEE; GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1465428 | CALIFORNIANS AGAINST PROPOSITION 1 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1465319 | YES ON PROPOSITION 1 - EXPANDING ACCESS TO MENTAL HEALTH SERVICES AND VETERANS' CARE SPONSORED BY CALIFORNIA MEDICAL ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1466023 | STATEWIDE CALIFORNIA COALITION SOLUTIONS COMMITTEE | SUPPORT